@@ -7,13 +7,12 @@ Elive -  Elluminate Live (c) client library
 
 =head1 VERSION
 
-Version 0.12
+Version 0.13
 
 =cut
 
-our $VERSION = '0.12';
+our $VERSION = '0.13';
 
-use Class::Data::Inheritable;
 use base qw{Class::Data::Inheritable};
 
 use Elive::Connection;
@@ -41,28 +40,33 @@ use Elive::Connection;
 
 =head1 DESCRIPTION
 
-Elluminate Live (c) is is a synchronous web tool for virtual online classrooms.
+Elive is designed to assist in then integration and automation of
+Elluminate Live sites. In particular, managing users and meetings.
+
+It provides Perl object bindings to entities via the Elluminate Live
+SOAP/XML command interface.
+
+=head1 BACKGROUND
+
+Elluminate Live (c) is is a web tool for virtual online classrooms.
 
 It is suitable for online collaboration, demonstrations, meetings, web
 conferences, seminars and IT deployment, training and support.
 
 Users, Meetings and other resources are stored in a management database.
-These can managed via the Elluminate Live web server. Most actions can also
-be performed via a Elluminate Live's SOAP/XML SDK.
+These can managed via the Elluminate Live web interface.
 
-Elive implements Perl object bindings for the Elluminate Live SOAP/XML SDK.
-
-It is designed to assist in then integration and automation of Elluminate
-Live sites. In particular, managing users and meetings..
+Most actions that can be performed via the web interface can also be
+driven from Elluminate Live's SOAP/XML command interface.
 
 =cut
 
-__PACKAGE__->mk_classdata('_login');
-__PACKAGE__->mk_classdata('_server_details');
 __PACKAGE__->mk_classdata('adapter' => 'default');
 
-our $DEBUG = $ENV{ELIVE_DEBUG};
-our $WARN = 1;
+our $DEBUG;
+BEGIN {
+    $DEBUG = $ENV{ELIVE_DEBUG};
+}
 
 =head1 METHODS
 
@@ -88,7 +92,7 @@ sub connect {
     die "usage: ${class}->new(url, login_name[, pass])"
 	unless ($class && $url && $login_name);
 
-    my $connection = Elive::Connection->new(
+    my $connection = Elive::Connection->connect(
 	$url,
 	$login_name,
 	$pass,
@@ -98,19 +102,11 @@ sub connect {
     $class->connection($connection);
 
     #
-    # The login name should be a valid user in the database
+    # The login name should be a valid user in the database.
     # retrieve it as a way of authenticating the user and
     # checking basic connectivity.
     #
-    eval "use  Elive::Entity::User";
-    die $@ if $@;
-
-    my $login_user = Elive::Entity::User->get_by_loginName($login_name);
-
-    die "Unable to connect via user $login_name"
-	unless $login_user;
-
-    $class->_login ($login_user);
+    $connection->login;
 
     return $connection;
 }
@@ -134,27 +130,14 @@ return the user entity used to connect to the server
 
 sub login {
     my $class = shift;
+    my %opt = @_;
 
-    my $connection = $class->connection
-	or die "not connected";
+    my $connection = $opt{connection} || $class->connection;
 
-    my $login_entity = $class->_login;
+    die "not connected"
+	unless $connection;
 
-    unless ($login_entity) {
-
-	my $username = $connection->user
-	    or return;
-
-	eval "use  Elive::Entity::Login";
-	die $@ if $@;
-
-	$login_entity = Elive::Entity::User->get_by_loginName($username)
-	    or die "unable to get login user: $username";
-
-	$class->_login($login_entity);
-    }
-
-    return $login_entity;
+    return $connection->login;
 }
 
 =head2 server_details
@@ -165,29 +148,14 @@ return the server details for entity for the current connection.
 
 sub server_details {
     my $class = shift;
+    my %opt = @_;
 
-    my $connection = $class->connection
-	or die "not connected";
+    my $connection = $opt{connection} || $class->connection;
 
-    my $server_details = $class->_server_details;
+    die "not connected"
+	unless $connection;
 
-    unless ($server_details) {
-
-	eval "use  Elive::Entity::ServerDetails";
-	die $@ if $@;
-
-	my $server_details_list = Elive::Entity::ServerDetails->list();
-
-	die "unable to get server details"
-	    unless (Elive::Util::_reftype($server_details_list) eq 'ARRAY'
-		    && $server_details_list->[0]);
-
-	$server_details = ($server_details_list->[0]);
-
-	$class->_server_details($server_details);
-    }
-
-    return $server_details;
+    return $connection->server_details;
 }
     
 =head2 disconnect
@@ -200,9 +168,10 @@ exiting your program
 sub disconnect {
     my $class = shift;
 
-    $class->_server_details(undef);
-    $class->_login(undef);
-    $class->connection(undef);
+    if (my $connection = $class->connection) {
+	$connection->disconnect;
+	$class->connection(undef);
+    }
 
     return undef;
 }
