@@ -36,6 +36,31 @@ The participants property is an array of Elive::Entity::Participant.
 
 =cut
 
+=head2 insert
+
+Note that for inserts, you only need to include the userId in the
+user records.  The following will be sufficient to associate two
+participants with a meeting.
+
+    my $participant_list = Elive::Entity::ParticipantList->insert(
+    {
+	meetingId => 123456,
+	participants => [
+	    {
+		user => {userId => 11111111}, #user id
+		role => {roleId => 2},
+	    },
+	    {
+		user => {userId => 22222222}, #user id
+		role => {roleId => 2},
+	    },
+	],
+    },
+    );
+
+=cut
+
+
 =head2 construct
 
     my $participant_list = Elive::Entity::ParticipantList->construct(
@@ -43,12 +68,12 @@ The participants property is an array of Elive::Entity::Participant.
 	meetingId => 123456,
 	participants => [
 	    {
-		user => 11111111, #user id
-		role => 2,
+		user => {userId => 11111111}, #user id
+		role => {roleId => 2},
 	    },
 	    {
-		user => 22222222, #user id
-		role => 2,
+		user => {userId => 22222222}, #user id
+		role => {roleId => 2},
 	    },
 	],
     },
@@ -94,24 +119,21 @@ sub _freeze {
 
     my $frozen = $class->SUPER::_freeze($data, %opt);
 
-    if ((my $participants = delete $frozen->{participants})
-	&& $opt{mode} =~ m{insert|update}i) {
+    if (my $participants = delete $frozen->{participants}) {
 	#
-	# We're using resetParticipantList, both for inserts and
-	# updates. This takes a stringified list of users as 'users'.
-	# The fetch mode returns the final list of 'particpiants'
+	# NOTE: thawed data is returned as the 'participants' property.
+        # but for frozen data the parmeter name is 'users'. Also
+        # setter methods expect a stringified digest in the form
+	#  userid=roleid[;userid=roleid]
 	#
 
 	die "expected participants to be an ARRAY"
 	    unless (Elive::Util::_reftype($participants) eq 'ARRAY');
 
 	my @users = map {
-	    my $str = UNIVERSAL::can($_,'stringify')
-		? $_->stringify
-		: $_;
+	    Elive::Entity::Participant->stringify($_);
 	} @$participants;
 
-
 	$frozen->{users} = join(';', @users);
     }
 
